Contains the exchange factory and implementation. The factory is the only thing needed for most users and is reexported from the root.
Structs
- Normalized
Cache Exchange - The normalized cache exchange. This will store normalized queries by unique ID.
- Normalized
Cache Impl - The implementation of the normalized cache. Exposed in case someone needs it, but most users shouldn’t.